; DGPS Radio Controller Software -- PIC16C73B, 16C76
; Copyright (c) 1998, 1999 Rich Heineck, All rights reserved.
; This program can be freely used for non-commercial purposes, and carries no warranty of any kind.
;
; File:		Startup.asm
; Date:		05/11/98
; Language:	Microchip 16CXX Assembler
;
;   This is the startup code that executes following a reset. All system initialization is 
;   done, and the mode select jumper is checked to determine whether to execute normal 
;   operating mode or the command line test mode. 
;
;  Change History
;	6/9/98	  Set up timer0 prescaler for 1:256
;   9/25/98   Changed version number to 0205
;   5/12/99	  Changed version to 0206
;	6/13/99   Added support for 16C73B - eliminated shared data space. 
;	          Changed version to 0207
;   1/7/00    $PSLIB J & K command support added (Landrum Haddix).
;             Enabled power-up timer in config and set version to 0208 (RH).
;   
;------------------------------------------------------------------------------

#define		SW_VERSION	H'0208'


	INCLUDE		<pic_hdr.inc>
#define	GLOB_DEF		; Disable EXTERN declaration for global variables
	INCLUDE		<dgps.inc>
	LIST		n=114, x=ON
	__CONFIG	_CP_OFF & _BODEN_ON & _WDT_OFF & _XT_OSC & _PWRTE_ON
	__IDLOCS	SW_VERSION



	EXTERN	NormalMode, TestMode, InitSynth, InitDemod, SetBitRate, SetFreq, RecallStation
	GLOBAL	SysState, arg1, arg2, CurrentFreq, CurrentBPS, PslibFlags


    
BANK0	UDATA
SysState	RES	1	;Used for program global system state flags
;
; The following vars for response to $PSLIB,,,K and $PSLIB,,,J NMEA
; commands. Allows StarLink MRB2A binary responses for the NMEA
; sentences.
;
CurrentFreq	RES	2	;Copy of current frequency x 100hz
				;Updated by SetFreq
CurrentBPS	RES	1	;Copy of current BPS value
				;Updated by SetBitRate
PslibFlags	RES	1	;Flags to allow NMEA message parser to
				;ask timer2_isr in demod.asm to 'slip in'
				;either a c1 or c5 starlink binary response
				;to a $PSLIB,,,J or K NMEA command. The
				;foreground routine can't call putch directly
				;because it is called by the ISR



	UDATA
;-- The following are used for passing arguments & return values between functions. 
arg1		RES	1
arg2		RES	1

;-- Local variables
NewBPS		RES	1


; If changing Timer 0 prescaler, also change TMR0_INT_RATE definition in NormMode.asm
INI_OPTION	EQU	7	; Timer 0: internal clk, pre = 1:256, PORTB pullups enabled



;==============================================================================
Reset	CODE	0
	goto	Start		; RESET vector




	CODE	
;------------------------------------------------------------------------------
;
;  RESET entry point. Execution begins here following power-up.
;

Start:
	banksel	OPTION_REG
	movlw	INI_OPTION
	movwf	OPTION_REG

	;-- Configure I/O ports
	banksel	PORTA
	clrf	PORTA		; Clear output latches first
	clrf	PORTB
	clrf	PORTC
	banksel	TRISA
	movlw	INI_TRISA
	movwf	TRISA
	movlw	INI_TRISB
	movwf	TRISB
	movlw	INI_TRISC
	movwf	TRISC
	movlw	INI_ADCON1
	movwf	ADCON1

	banksel	SysState
	clrf	SysState

	;-- Initialize SSP
	call	InitSynth
	
	;-- Initialize CCP's & Timers
	call	InitDemod


	;-- Retrieve last tuned station from EEPROM and set HW & SW to receive it
	call	RecallStation	; Returns freq in arg2:arg1, BPS in W
	banksel	NewBPS
	movwf	NewBPS		; Temporarily save 
	call	SetFreq		; Freq passed in arg2:arg1
	banksel	NewBPS
	movfw	NewBPS
	call	SetBitRate	; BPS code passed in W

	clrf	PslibFlags	;Say no starlink bin messages to send

	;-- UART gets initialized by NormalMode or TestMode routines
	

	; Initialization Done. Check mode pin to determine operating mode then begin
	; executing the selected mode.

	banksel	PORTB
	btfsc	OP_MODE_SEL
	goto	NormalMode
	goto	TestMode
	
	

	END





									
