	NOLIST
; DGPS Radio Controller Software -- PIC16C73B
; Copyright (c) 1998, Rich Heineck, All rights reserved.
; This program can be freely used for non-commercial purposes, and carries no warranty of any kind.
;
; File:		dgps.inc
; Date:		04/30/98
; Language:	Microchip 16CXX Assembler
;
;   Global Include file for source files. Contains system-wide definitions.
;
;  Change History
;	 6/8/98	  Changed Extern definition for AtoNum function to AtoFP1Num, which uses fixed
;			  point format, allowing tuning of international stations on 0.5 kHz boundaries.
;
;  10/01/98   Added definition for 4800 bps and assigned RB1 as serial comm rate select pin
;	6/12/99   16C73B migration - eliminated shared data space. 
;
;------------------------------------------------------------------------------

	CONSTANT	SYS_CLOCK = D'4000000'	; 4 MHz 

;-- UART baud rates   (BRGH=1):   SPBRG = ((Fosc / Bit Rate) / 16) - 1   ; Fosc = Xtal Freq
INI_SPBRG48		EQU D'51'		; 4800 bps for 4MHz clock
INI_SPBRG96		EQU	D'25'		; 9600 bps 
INI_SPBRG192	EQU	D'12'		; 19200 bps 

#define _bank0_	 TMR2			; Used for 'banksel' instruction. TMR2 is exclusive to bank 0

;------------------------------------------------
; Indirect addressing bank select macro for 16C76
;  	Note: MPASM doesn't work with IFDEF nested inside macro.
	IFDEF	__16C76
Banki_Sel	MACRO	bnk
		bankisel	bnk
		ENDM
	ELSE
Banki_Sel	MACRO	bnk
		ENDM
	ENDIF
;------------------------------------------------

  IFNDEF	GLOB_DEF
	EXTERN	SysState, arg1, arg2	; Global vars used for system state & argument / return value passing
  ENDIF

  IFNDEF	SERIAL_DEF
	EXTERN	init_uart, getch, putch
  ENDIF 


  IFNDEF	COMMAND_DEF
	EXTERN	InitCmd, CollectCmd, GetCmdChr, FindChr, AtoFP1Num
  ENDIF 


; Global interrupt enable / disable macros
#define  DisableInt		bcf	INTCON,GIE
#define  EnableInt		bsf	INTCON,GIE


;-- Data bit rate. Values are multipliers for 2.5 ms data clock reference (timer2).

BPS_200		EQU	2
BPS_100		EQU	4
BPS_50		EQU	8
;
; Bit definitions for PslibFlags starlink binary response messages
;
C5MSG		EQU	1
C1MSG		EQU	2

; Bit definitions for SysState global state variable
TESTMODE	EQU	0	; Bit set if test mode is active
LOCKED		EQU	1	; Bit set if LOCK is established


;-- I/O Port Configuration, Definitions, and I/O Pin Assignments

INI_TRISA	EQU	0			; All outputs
INI_TRISB	EQU	B'00001110'	; RB1-RB3:input; all others output
INI_TRISC	EQU	B'11010110'	; RC0 available as general output. All others are used 
							;   for UART, SPI, CCP.
INI_ADCON1	EQU	6			; Set all PORTA pins to digital I/O



#define BIT_CLOCK_TP	PORTA,1		; Test Point: Regenerated bit clock (SW PLL)
#define RAW_DATA_TP		PORTA,2		; Test Point: LP filtered data (used for edge detect)
#define DATA_BIT_TP		PORTA,3		; Test Point: Demodulated data
#define SYN_ENB			PORTA,5		; Drives MC145157 ENB line

#define	COM_RATE_SEL	PORTB,1		; INPUT		1 = 4800bps, 0 (jmp to gnd) = 9600bps
#define	OP_MODE_SEL		PORTB,2		; INPUT		1 = normal mode, 0 (short to gnd) = test mode
#define EE_DOUT			PORTB,3		; INPUT		EEPROM Data Out
#define EE_DIN			PORTB,4		; OUTPUT	EEPROM Data In
#define EE_CLK			PORTB,5		; OUTPUT	EEPROM Clock
#define EE_CS			PORTB,6		; OUTPUT	EEPROM Chip Select
#define LOCK_LED		PORTB,7		; OUTPUT


	LIST
